==> spip_4.4.3+dfsg.orig.tar.xz: plugins-dist/medias/lib/mejs/lang/fa.js <==
/*!
 * This is a `i18n` language object.
 *
 * Persian
 *
 * @author
 *   wmateam (GitHub: @wmateam)
 *
 * @see core/i18n.js
 */
(function (exports) {
    'use strict';
    
    if (exports.fa === undefined) {
        exports.fa = {
            'mejs.plural-form': 0,
            'mejs.download-file': 'دریافت فایل',
            'mejs.fullscreen': 'تمام صفحه',
            'mejs.play': 'پخش',
            'mejs.pause': 'توقف',
            'mejs.time-slider': 'تغییر زمان',
            'mejs.time-help-text': 'از کلید های چپ و راست کیبورد برای جا به جایی به میزان یک ثانیه استفاده کنید.همچنین کلید های بالا و پایین 10 ثانیه زمان را جا به جا می کند.',
            'mejs.live-broadcast': 'پخش زنده',
            'mejs.volume-help-text': 'از دکمه های بالا و پایین برای کم و زیاد کردن حجم صدا استفاده کنید.',
            'mejs.unmute': 'صدا دار',
            'mejs.mute': 'بی صدا',
            'mejs.volume-slider': 'تغییر حجم صدا',
            'mejs.video-player': 'پخش کننده ویدیو',
            'mejs.audio-player': 'پخش کننده صدا',
            'mejs.captions-subtitles': 'زیرنویس',
            'mejs.captions-chapters': 'قسمت',
            'mejs.none': 'هیچ',
            'mejs.afrikaans': 'آفریقایی',
            'mejs.albanian': 'آلبانیایی',
            'mejs.arabic': 'عربی',
            'mejs.belarusian': 'بلاروس',
            'mejs.bulgarian': 'بلغاری',
            'mejs.catalan': 'کاتالان',
            'mejs.chinese': 'چینی',
            'mejs.chinese-simplified': 'چینی (ساده شده)',
            'mejs.chinese-traditional': 'چینی (سنتی)',
            'mejs.croatian': 'کروات',
            'mejs.czech': 'چک',
            'mejs.danish': 'دانمارکی',
            'mejs.dutch': 'هلندی',
            'mejs.english': 'انگلیسی',
            'mejs.estonian': 'استونی',
            'mejs.filipino': 'فیلیپینی',
            'mejs.finnish': 'فنلاندری',
            'mejs.french': 'فرانسوی',
            'mejs.galician': 'گالیسی',
            'mejs.german': 'آلمانی',
            'mejs.greek': 'یونانی',
            'mejs.haitian-creole': 'کریول هائیتی',
            'mejs.hebrew': 'عبری',
            'mejs.hindi': 'هندی',
            'mejs.hungarian': 'مجارستانی',
            'mejs.icelandic': 'ایسلندی',
            'mejs.indonesian': 'اندونزی',
            'mejs.irish': 'ایرلندی',
            'mejs.italian': 'ایتالیایی',
            'mejs.japanese': 'ژاپنی',
            'mejs.korean': 'کره ای',
            'mejs.latvian': 'لتونی',
            'mejs.lithuanian': 'لیتوانی',
            'mejs.macedonian': 'مقدونی',
            'mejs.malay': 'مالایی',
            'mejs.maltese': 'مالتی',
            'mejs.norwegian': 'نروژی',
            'mejs.persian': 'فارسی',
            'mejs.polish': 'لهستانی',
            'mejs.portuguese': 'پرتغالی',
            'mejs.romanian': 'روانی',
            'mejs.russian': 'روسی',
            'mejs.serbian': 'صرب',
            'mejs.slovak': 'اسلواکی',
            'mejs.slovenian': 'اسلوونیایی',
            'mejs.spanish': 'اسپانیایی',
            'mejs.swahili': 'سواحیلی',
            'mejs.swedish': 'سوئد',
            'mejs.tagalog': 'تاگالوگ',
            'mejs.thai': 'تایلندی',
            'mejs.turkish': 'ترکی',
            'mejs.ukrainian': 'اوکراین',
            'mejs.vietnamese': 'ویتنامی',
            'mejs.welsh': 'ولزی',
            'mejs.yiddish': 'ییدیش'
        };
    }
})(mejs.i18n);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/medias/lib/mejs/lang/fa.js <==
/*!
 * This is a `i18n` language object.
 *
 * Persian
 *
 * @author
 *   wmateam (GitHub: @wmateam)
 *
 * @see core/i18n.js
 */
(function (exports) {
    'use strict';    if (exports.fa === undefined) {
        exports.fa = {
            'mejs.plural-form': 0,
            'mejs.download-file': 'دریافت فایل',
            'mejs.fullscreen': 'تمام صفحه',
            'mejs.play': 'پخش',
            'mejs.pause': 'توقف',
            'mejs.time-slider': 'تغییر زمان',
            'mejs.time-help-text': 'از کلید های چپ و راست کیبورد برای جا به جایی به میزان یک ثانیه استفاده کنید.همچنین کلید های بالا و پایین 10 ثانیه زمان را جا به جا می کند.',
            'mejs.live-broadcast': 'پخش زنده',
            'mejs.current': 'زمان فعلی',
            'mejs.duration': 'مدت زمان کل',
            'mejs.volume-help-text': 'از دکمه های بالا و پایین برای کم و زیاد کردن حجم صدا استفاده کنید.',
            'mejs.unmute': 'صدا دار',
            'mejs.mute': 'بی صدا',
            'mejs.volume-slider': 'تغییر حجم صدا',
            'mejs.video-player': 'پخش کننده ویدیو',
            'mejs.audio-player': 'پخش کننده صدا',
            'mejs.captions-subtitles': 'زیرنویس',
            'mejs.captions-chapters': 'قسمت',
            'mejs.none': 'هیچ',
            'mejs.afrikaans': 'آفریقایی',
            'mejs.albanian': 'آلبانیایی',
            'mejs.arabic': 'عربی',
            'mejs.belarusian': 'بلاروس',
            'mejs.bulgarian': 'بلغاری',
            'mejs.catalan': 'کاتالان',
            'mejs.chinese': 'چینی',
            'mejs.chinese-simplified': 'چینی (ساده شده)',
            'mejs.chinese-traditional': 'چینی (سنتی)',
            'mejs.croatian': 'کروات',
            'mejs.czech': 'چک',
            'mejs.danish': 'دانمارکی',
            'mejs.dutch': 'هلندی',
            'mejs.english': 'انگلیسی',
            'mejs.estonian': 'استونی',
            'mejs.filipino': 'فیلیپینی',
            'mejs.finnish': 'فنلاندری',
            'mejs.french': 'فرانسوی',
            'mejs.galician': 'گالیسی',
            'mejs.german': 'آلمانی',
            'mejs.greek': 'یونانی',
            'mejs.haitian-creole': 'کریول هائیتی',
            'mejs.hebrew': 'عبری',
            'mejs.hindi': 'هندی',
            'mejs.hungarian': 'مجارستانی',
            'mejs.icelandic': 'ایسلندی',
            'mejs.indonesian': 'اندونزی',
            'mejs.irish': 'ایرلندی',
            'mejs.italian': 'ایتالیایی',
            'mejs.japanese': 'ژاپنی',
            'mejs.korean': 'کره ای',
            'mejs.latvian': 'لتونی',
            'mejs.lithuanian': 'لیتوانی',
            'mejs.macedonian': 'مقدونی',
            'mejs.malay': 'مالایی',
            'mejs.maltese': 'مالتی',
            'mejs.norwegian': 'نروژی',
            'mejs.persian': 'فارسی',
            'mejs.polish': 'لهستانی',
            'mejs.portuguese': 'پرتغالی',
            'mejs.romanian': 'روانی',
            'mejs.russian': 'روسی',
            'mejs.serbian': 'صرب',
            'mejs.slovak': 'اسلواکی',
            'mejs.slovenian': 'اسلوونیایی',
            'mejs.spanish': 'اسپانیایی',
            'mejs.swahili': 'سواحیلی',
            'mejs.swedish': 'سوئد',
            'mejs.tagalog': 'تاگالوگ',
            'mejs.thai': 'تایلندی',
            'mejs.turkish': 'ترکی',
            'mejs.ukrainian': 'اوکراین',
            'mejs.vietnamese': 'ویتنامی',
            'mejs.welsh': 'ولزی',
            'mejs.yiddish': 'ییدیش'
        };
    }
})(mejs.i18n);
